# arxiv2bib

Search papers on arxiv2bib and save as bibtex

## Installation
``
pip install arxiv2bib
``

## Usage
``
arxiv2bib --query "variational autoencoders" --out sample.bib --start 0 --max 1000
``

* query: search query
* out: path to output file
* start: starting index of the search
* max: max results